``eradiate.exceptions``
=======================

.. automodule:: eradiate.exceptions

.. py:currentmodule:: eradiate.exceptions

Exceptions
----------

.. autoclass:: KernelVariantError

.. autoclass:: ModeError

.. autoclass:: TraversalError

.. autoclass:: UnsupportedModeError


Warnings
--------

.. autoclass:: ConfigWarning

.. autoclass:: OverriddenValueWarning
